import { registryScript } from "../utils.mjs";
import { boolean, object, optional, string } from "#nuxt-scripts-validator";
export const MatomoAnalyticsOptions = object({
  matomoUrl: string(),
  // site is required
  siteId: string(),
  trackPageView: optional(boolean()),
  enableLinkTracking: optional(boolean())
});
export function useScriptMatomoAnalytics(_options) {
  return registryScript("matomoAnalytics", (options) => ({
    scriptInput: {
      src: `https://${options?.matomoUrl}/matomo.js`
    },
    schema: import.meta.dev ? MatomoAnalyticsOptions : void 0,
    scriptOptions: {
      use() {
        return { _paq: window._paq };
      },
      // allow _paq to be accessed on the server
      stub: import.meta.client ? void 0 : ({ fn }) => {
        return fn === "_paq" ? [] : void 0;
      },
      clientInit: import.meta.server ? void 0 : () => {
        const _paq = window._paq = window._paq || [];
        options?.trackPageView !== false && _paq.push(["trackPageView"]);
        options?.enableLinkTracking !== false && _paq.push(["enableLinkTracking"]);
        _paq.push(["setTrackerUrl", `//${options?.matomoUrl}/matomo.php`]);
        _paq.push(["setSiteId", options?.siteId]);
      }
    }
  }), _options);
}
