import { registryScript } from "../utils.mjs";
import { PlausibleAnalyticsScriptResolver } from "../../registry";
import { array, literal, object, optional, string, union } from "#nuxt-scripts-validator";
const extensions = [
  literal("hash"),
  literal("outbound-links"),
  literal("file-downloads"),
  literal("tagged-events"),
  literal("revenue"),
  literal("pageview-props"),
  literal("compat"),
  literal("local"),
  literal("manual")
];
export const PlausibleAnalyticsOptions = object({
  domain: string(),
  // required
  extension: optional(union([union(extensions), array(union(extensions))]))
});
export function useScriptPlausibleAnalytics(_options) {
  return registryScript("plausibleAnalytics", (options) => {
    return {
      scriptInput: {
        "src": PlausibleAnalyticsScriptResolver(options),
        "data-domain": options?.domain
      },
      schema: import.meta.dev ? PlausibleAnalyticsOptions : void 0,
      scriptOptions: {
        use() {
          return { plausible: window.plausible };
        }
      }
    };
  }, _options);
}
