import { registryScript } from "../utils.mjs";
import { SegmentScriptResolver } from "../../registry";
import { object, optional, string } from "#nuxt-scripts-validator";
export const SegmentOptions = object({
  writeKey: string(),
  analyticsKey: optional(string())
});
export function useScriptSegment(_options) {
  return registryScript("segment", (options) => {
    const analyticsKey = options?.analyticsKey || "analytics";
    return {
      scriptInput: {
        "data-global-segment-analytics-key": analyticsKey,
        "src": SegmentScriptResolver(options)
      },
      schema: import.meta.dev ? SegmentOptions : void 0,
      scriptOptions: {
        use() {
          return { analytics: window[analyticsKey] };
        },
        clientInit: import.meta.server ? void 0 : () => {
          window.analytics = window.analytics || [];
          window.analytics.methods = ["track", "page", "identify", "group", "alias", "reset"];
          window.analytics.factory = function(method) {
            return function(...params) {
              const args = Array.prototype.slice.call(params);
              args.unshift(method);
              window.analytics.push(args);
              return window.analytics;
            };
          };
          for (let i = 0; i < window.analytics.methods.length; i++) {
            const key = window.analytics.methods[i];
            window.analytics[key] = window.analytics.factory(key);
          }
          window.analytics.page();
        }
      }
    };
  }, _options);
}
