import { defu } from "defu";
import { parse } from "#nuxt-scripts-validator";
import { createError, useRuntimeConfig, useScript } from "#imports";
function validateScriptInputSchema(key, schema, options) {
  if (import.meta.dev) {
    try {
      parse(schema, options);
    } catch (e) {
      createError({
        cause: e,
        message: `Invalid script options for ${key}`
      });
    }
  }
}
export function registryScript(key, optionsFn, _userOptions) {
  const runtimeConfig = useRuntimeConfig().public.scripts || {};
  const runtimeOptions = runtimeConfig[key];
  const userOptions = Object.assign(_userOptions || {}, runtimeOptions || {});
  const options = optionsFn(userOptions);
  const scriptInput = defu(options.scriptInput, { key });
  const scriptOptions = Object.assign(_userOptions?.scriptOptions || {}, options.scriptOptions || {});
  const init = scriptOptions.beforeInit;
  scriptOptions.beforeInit = () => {
    import.meta.dev && options.schema && validateScriptInputSchema(key, options.schema, userOptions);
    init?.();
    import.meta.client && options.clientInit?.();
  };
  return useScript(scriptInput, scriptOptions);
}
